//
//  EditarSitioViewController.m
//  RouteOptimizer
//
//  Created by Carlos Giménez on 21/04/13.
//  Copyright (c) 2013 Carlos Giménez. All rights reserved.
//

#import "EditarSitioViewController.h"
#import "MQViewController.h"
#import <sqlite3.h>
#import "AppDelegate.h"
#import "listaDireccionesViewController.h"

@interface EditarSitioViewController ()

@end

@implementation EditarSitioViewController
@synthesize textAdresa;
@synthesize textClau;
@synthesize padre;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

/*
 Carrega l'element indicador i carrega el formulari amb les dades de la cel·la que hem seleccionat.
 */


- (void)viewDidLoad
{
    [super viewDidLoad];
    
    myIndicator = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleGray];
    
    NSIndexPath *indexPath = padre.tableView.indexPathForSelectedRow;
    
    if (indexPath.section==0) {
        self.textAdresa.text = [[padre.origen objectAtIndex:0] objectForKey:@"adresa"];
        self.textClau.text = [[padre.origen objectAtIndex:0] objectForKey:@"titol"];
    }
    
    else {
        self.textAdresa.text = [[padre.destinos objectAtIndex:indexPath.row] objectForKey:@"adresa"];
        self.textClau.text = [[padre.destinos objectAtIndex:indexPath.row] objectForKey:@"titol"];
    }
    // Do any additional setup after loading the view.
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

/*
 Un cop introduïda una adreça, la valida amb el geocodificador i la introdueix a la nostra taula, o si no és vàlida, mostra un error de geocodificació.
 */

- (IBAction)pulsarAceptar:(id)sender {
    [self lockUI]; //Bloqueja l'aplicació mentre s'executa l'acció
    
    NSIndexPath *indexPath = padre.tableView.indexPathForSelectedRow;
    
    //Si s'ha deixat el formulari amb el text per defecte, mostra una alerta avisant que s'ha d'introduir una adreça
    
    if ([self.textAdresa.text isEqualToString:@"Nova adreça"]) {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"No hi ha adreça!" message:@"Has d'introduir una adreça" delegate:self cancelButtonTitle:@"OK" otherButtonTitles: nil];
        [alert show];
    }
    
    else {
        NSDictionary *dic = [[NSDictionary alloc] initWithObjects:[NSArray arrayWithObjects:self.textAdresa.text, self.textClau.text, nil] forKeys:[NSArray arrayWithObjects:@"adresa", @"titol",nil]]; //Adreça a introduir
        __block NSDictionary *dic2; //Dades de l'adreça finals
        __block bool seacabo = false; //Control de la tasca asíncrona
        CLGeocoder *geocoder = [[CLGeocoder alloc] init];
        [geocoder geocodeAddressString:[dic objectForKey:@"adresa"] completionHandler:^(NSArray *placemarks, NSError *error) {
            if (error) {
                /*
                 Si no es troba una adreça que s'assembli al text posat, mostra una alerta.
                 */
                NSLog(@"Error");
                [self unlockUI];
                UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Adreça no vàlida!" message:@"Has d'introduir una adreça vàlida" delegate:self cancelButtonTitle:@"OK" otherButtonTitles: nil];
                [alert show];
                return;
            }
            CLPlacemark *placemark = [placemarks objectAtIndex:0]; //Agafa el primer resultat entre les possibles opcions.
            dic2 = [[NSDictionary alloc] initWithObjects:[NSArray arrayWithObjects:[self placemarkToString: placemark], [dic objectForKey:@"titol"], nil] forKeys:[NSArray arrayWithObjects: @"adresa", @"titol",nil]]; //Crea l'objecte per actualitzar la taula, afegida placemark
            seacabo = true; //Fi de la tasca asíncrona
        }];
        
        /*
         Mentre dura la tasca asíncrona, no s'executa cap instrucció
         */
        while (!seacabo) {
            NSDate *oneSecond = [NSDate dateWithTimeIntervalSinceNow:1];
            [[NSRunLoop currentRunLoop] runMode:NSDefaultRunLoopMode beforeDate:oneSecond];
        }
        
        /*
         S'afegeix al registre corresponent
         */
        if (indexPath.section==0) {
            [padre.origen replaceObjectAtIndex:indexPath.row withObject:dic2];
        }
        else {
            [padre.destinos replaceObjectAtIndex:indexPath.row withObject:dic2];
        }
        [padre.tableView reloadData]; //Actualitza la vista de la taula
        [self unlockUI]; //Desbloqueja l'aplicació ja que ja ha acabat tot.
        seacabo = false; //Es torna a inicialitzar el booleà per poder controlar una altra tasca asíncrona
        [self dismissViewControllerAnimated:YES completion:nil]; //Torna a la vista principal
    }
}

/*
 Si es prem el botó Cancelar, es torna a la vista original sense fer canvis.
 */

- (IBAction)pulsarCancelar:(id)sender {
    [self dismissViewControllerAnimated:YES completion:nil];
}

/*
 Si es prem el botó esborrar, s'esborra l'adreça i es torna a la vista anterior.
 */

- (IBAction)pulsarBorrar:(id)sender {
    NSIndexPath *indexPath = padre.tableView.indexPathForSelectedRow;
    
    //Control per no esborrar l'adreça d'origen
    
    if (indexPath.section==0){
        UIAlertView *alert =[[UIAlertView alloc] initWithTitle:@"No es pot fer" message:@"A la ruta hi ha d'haver origen!" delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil];
        [alert show];
    }
    else {
        [padre.destinos removeObjectAtIndex:indexPath.row];
        [padre.tableView reloadData];
        [self dismissViewControllerAnimated:YES completion:nil]; //Torna a la vista anterior
    }
                            
}

/*
 S'agafa la posició actual i s'introdueix com a destinació o origen
 */

- (IBAction)insertarUbicacion:(id)sender {
    [self lockUI]; //Bloqueja l'aplicació mentre dura la tasca.
    CLGeocoder *geocoder = [[CLGeocoder alloc] init];
    NSIndexPath *indexPath = padre.tableView.indexPathForSelectedRow;
    
    /*
     Localització de l'usuari
     */
    CLLocationManager *locationManager = [[CLLocationManager alloc] init];
    locationManager.distanceFilter = kCLDistanceFilterNone;
    locationManager.desiredAccuracy = kCLLocationAccuracyBest;
    [locationManager startUpdatingLocation];
    CLLocation *location = [locationManager location];
    
    
    __block NSDictionary *dic2;
    __block bool seacabo = false; //Control de la tasca asíncrona
    
    /*
     Conversió de la posició actual en coordenades 2D i després en adreça, amb geocodificació inversa.
     */
    
    [geocoder reverseGeocodeLocation:location completionHandler:^(NSArray *placemarks, NSError *error) {
        if (error){
            NSLog(@"Geocode failed with error: %@", error);
            return;
        }
        CLPlacemark *placemark= [placemarks objectAtIndex:0];
        dic2 = [[NSDictionary alloc] initWithObjects:[NSArray arrayWithObjects:[self placemarkToString: placemark], @"Ubicació actual", nil] forKeys:[NSArray arrayWithObjects: @"adresa", @"titol",nil]];
        seacabo = true; //Fi de la tasca asíncrona
    }];
    
    // Espera mentre s'executa la tasca asíncrona
    
    while (!seacabo) {
        NSDate *oneSecond = [NSDate dateWithTimeIntervalSinceNow:1];
        [[NSRunLoop currentRunLoop] runMode:NSDefaultRunLoopMode beforeDate:oneSecond];
    }
    
    //S'introdueix a la taula la nostra adreça
    if (indexPath.section==0) {
        [padre.origen replaceObjectAtIndex:indexPath.row withObject:dic2];
    }
    else {
        [padre.destinos replaceObjectAtIndex:indexPath.row withObject:dic2];
    }
    [padre.tableView reloadData]; //Reiniciem les dades
    [self unlockUI]; //Desbloqueja l'aplicació
    [self dismissViewControllerAnimated:YES completion:nil]; //Torna a la vista anterior
    
}

//Per a utilitzar en futures versions. Introducció d'adreces de contactes.

- (IBAction)importarDireccion:(id)sender {
}

/*
 Acció per afegir una adreça a la nostra base de dades de favorits.
 */

- (IBAction)inserirAdresa:(id)sender {
    [self lockUI]; //Bloqueja l'aplicació mentre s'executa
    
    //Inicialització de la base de dades
    AppDelegate *appDelegate = (AppDelegate *) [[UIApplication sharedApplication] delegate];
    sqlite3 *database;
    sqlite3_stmt *sentencia;
    
    if (sqlite3_open([appDelegate.databasePath UTF8String], &database)==SQLITE_OK) { //Obrim la base de dades
        NSString *sql =[NSString stringWithFormat:@"insert into direcciones (\"Direccion\",\"Clave\") VALUES (\"%@\",\"%@\")", self.textAdresa.text, self.textClau.text];
        if (sqlite3_prepare_v2(database, [sql UTF8String], -1, &sentencia, NULL)==SQLITE_OK) { //Preparem la sentència SQL
            while(sqlite3_step(sentencia)==SQLITE_OK) {
               //Introducció de dades a la SQL
            }
          
        }
        else {
            NSLog(@"Error en la creacion del insert"); //Error amb la sentència
        }
        sqlite3_finalize(sentencia);
    }
    else {
        NSLog(@"No se ha podido abrir la base de datos"); //Error obrint la base de dades
    }
    sqlite3_close(database); //Tanquem base de dades
    [self unlockUI]; //Desbloquegem l'aplicació
    
}

// Per retirar el teclat un cop hem introduit text

-(BOOL) textFieldShouldReturn:(UITextField *) textField{
    return [textField resignFirstResponder];
}

// Per bloquejar l'aplicació mentre s'executa una tasca

-(void) lockUI {
    
    /*
     Indicador d'execució d'una tasca.
     */
    myIndicator.color = [UIColor redColor];
    myIndicator.center = self.view.center;
    [self.view addSubview:myIndicator];
    [myIndicator startAnimating];
    
    /*
     Bloqueig de botons i de barra d'opcions
     */
    
    [self.view setUserInteractionEnabled:NO];
    [self.tabBarController.view setUserInteractionEnabled:NO];
}

//Per desbloquejar l'aplicació quan acaba la tasca

-(void) unlockUI {
    
    [myIndicator stopAnimating]; //Desapareix l'indicador
    [self.view setUserInteractionEnabled:YES]; //Desbloqueja botons
    [self.tabBarController.view setUserInteractionEnabled:YES]; //Desbloqueja barra d'opcions
}

/*
 Converteix un element Placemark en un String per mostrar a la nostra taula, que contingui Carrer amb nombre i Població. Si no es troba el nom del carrer, almenys mostrarà la població.
 */

-(NSString *) placemarkToString: (CLPlacemark *) placemark {
    NSString *str = @"";
    if (placemark.thoroughfare.length>0) {
    str = [str stringByAppendingString: placemark.thoroughfare];
    str = [str stringByAppendingString:@", "];
    }
    if (placemark.subThoroughfare.length>0) {
    str = [str stringByAppendingString:placemark.subThoroughfare];
    str = [str stringByAppendingString:@", "];
    }
    str = [str stringByAppendingString:placemark.locality];
    return str;
    return placemark.locality;

}

/*
 Quan es prem el botó Importar Adreça, s'envia a la vista de la base de dades amb la informació necessària d'aquesta vista.
 */

-(void) prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    if([segue.identifier isEqualToString:@"ImportarDireccion"]) {
        listaDireccionesViewController *lVC = [segue destinationViewController];
        lVC.padre = self;
    }
}

@end
