//
//  MQViewController.m
//  RouteOptimizer
//
//  Created by Carlos Giménez on 19/04/13.
//  Copyright (c) 2013 Carlos Giménez. All rights reserved.
//

#import "MQViewController.h"
#import "ViewController.h"
#import "origenAnnotation.h"
#import "destinosAnnotation.h"

@implementation MQViewController
@synthesize mapView;

/*
 Inicialització de la vista el mapa, la centrem sobre Catalunya per començar, tot i que al afegir els punts canvia el centre de la imatge.
 */

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    CGRect mapFrame = CGRectMake(0, 0, self.view.frame.size.width, self.view.frame.size.height);
    
    mapView = [[MQMapView alloc] initWithFrame:mapFrame];
    mapView.delegate = self;
    
    [self.view addSubview:mapView];
    [self.view sendSubviewToBack:mapView];
    
    [mapView setRegion:MQCoordinateRegionBetweenCoords(CLLocationCoordinate2DMake(41.3, 2.1), CLLocationCoordinate2DMake(41.5, 2.2))];
    
   	// Do any additional setup after loading the view.
}

/*
 
 Funció per afegir un pin al mapa, un cop creat un element de la classe MQAnnotation
 
*/

-(MQAnnotationView*)mapView:(MQMapView *)aMapView viewForAnnotation:(id<MQAnnotation>)annotation {
    
    MQAnnotationView *pinView = nil;
    
    //Si el pin és de la classe origen, es pintarà de color lila i centrarem la imatge en aquest pin.
    
    if ([annotation isKindOfClass:[origenAnnotation class]]){
        static NSString* identifier = @"pinAnnotations";
        pinView = (MQPinAnnotationView *) [aMapView dequeueReusableAnnotationViewWithIdentifier:identifier];
        if (!pinView) {
            // Si no hi havia cap pin, es crea un
            MQPinAnnotationView* customPinView = [[MQPinAnnotationView alloc]
                                                  initWithAnnotation:annotation reuseIdentifier:identifier];
            customPinView.pinColor = MQPinAnnotationColorPurple;
            customPinView.animatesDrop = YES;
            customPinView.canShowCallout = YES;
            
            UIButton* leftButton = [UIButton buttonWithType:UIButtonTypeInfoLight];
            
            customPinView.leftCalloutAccessoryView = leftButton;
            pinView = customPinView;
        }
        else{
            pinView.annotation = annotation;
        }
    }
    
    //Si el pin és de la classe destinació, es pintarà de color vermell.
    
    if ([annotation isKindOfClass:[destinosAnnotation class]]){
        static NSString* identifier = @"pinAnnotations";
        pinView = (MQPinAnnotationView *) [aMapView dequeueReusableAnnotationViewWithIdentifier:identifier];
        if (!pinView) {
            // Si no hi havia cap pin, es crea un
            MQPinAnnotationView* customPinView = [[MQPinAnnotationView alloc]
                                                   initWithAnnotation:annotation reuseIdentifier:identifier];
            customPinView.pinColor = MQPinAnnotationColorRed;
            customPinView.animatesDrop = YES;
            customPinView.canShowCallout = YES;
            
            UIButton* leftButton = [UIButton buttonWithType:UIButtonTypeInfoLight];
            
            customPinView.leftCalloutAccessoryView = leftButton;
            pinView = customPinView;
        }
        else{
            pinView.annotation = annotation;
                                                  }
                                }
    return pinView;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

/*
 
 Actualització de la vista cada cop que la fem aparèixer. 
 
 */

-(void) viewDidAppear:(BOOL)animated {
    [super viewDidAppear:animated];
    __block bool seacabo = false; // Control de la tasca asíncrona
    NSArray *someAnnotations = [mapView annotations];
    [mapView removeAnnotations:someAnnotations]; // S'eliminen totes les anotacions anteriors per reiniciar el mapa.
    mapView.showsUserLocation=YES; //Per mostrar la ubicació de l'usuari
    ViewController *padre = [[self.tabBarController viewControllers] objectAtIndex:0]; // Per accedir a les taules on apareixen les adreces.
    
    /*
    En aquest fragment de codi, s'executen les instruccions per geocodificar el String que indica l'adreça, convertir-ho en coordenades GPS i posteriorment s'afegeix al mapa amb un pin, amb les adreces d'origen.
     */
    
    
    for (int i=0; i<[padre.origen count]; i++) {
        CLGeocoder *geocoder = [[CLGeocoder alloc] init];
        NSDictionary *dic = [padre.origen objectAtIndex:i]; //Codificació de l'origen
        [geocoder geocodeAddressString:[dic objectForKey:@"adresa"] completionHandler:^(NSArray *placemarks, NSError *error) {
            if (error) {
                NSLog(@"Error");
                return;
            }
            CLPlacemark *placemark = [placemarks objectAtIndex:0]; //Dona per bo el primer resultat de la geoodificació
            
            /* 
             Es crea l'anotació que posteriorment s'afegirà amb un pin a la nostra vista.
             */
            
            origenAnnotation *nota = [[origenAnnotation alloc] initWithCoordinate:CLLocationCoordinate2DMake(placemark.location.coordinate.latitude, placemark.location.coordinate.longitude) title:@"Origen" subTitle:[[padre.origen objectAtIndex:i] objectForKey:@"titol"]];
            
            [mapView addAnnotation:nota];
            [mapView setCenterCoordinate:nota.coordinate];
            seacabo = true; // Per indicar que acaba la tasca asíncrona
        }];
        /*
         Mentre no hagi acabat la geocodificació, l'aplicació esperarà sense executar cap altra acció.
         */
        
        while (!seacabo) {
            NSDate *oneSecond = [NSDate dateWithTimeIntervalSinceNow:1];
            [[NSRunLoop currentRunLoop] runMode:NSDefaultRunLoopMode beforeDate:oneSecond];
        }
        seacabo = false; // Un cop segurs que ja s'ha carregat bé l'anotació, es torna a posar a fals per executar el segon grup d'instruccions.
    }
    
    /*
     En aquest fragment de codi, s'executen les mateixes instruccions, però ara amb les destinacions.
     */
    
    
    
    for (int i=0; i<[padre.destinos count]; i++) {
        CLGeocoder *geocoder = [[CLGeocoder alloc] init];
        NSDictionary *dic = [padre.destinos objectAtIndex:i];
        [geocoder geocodeAddressString:[dic objectForKey:@"adresa"] completionHandler:^(NSArray *placemarks, NSError *error) {
            if (error) {
                NSLog(@"Error");
                return;
            }
            CLPlacemark *placemark = [placemarks objectAtIndex:0];
            
            /*
             Cada destinació es mostra amb un nombre i el nom clau que s'hagi triat (si és el cas)
             */
            
            NSString *paraula = [NSString stringWithFormat:@"Destinació %i", i+1];            destinosAnnotation *nota = [[destinosAnnotation alloc] initWithCoordinate:CLLocationCoordinate2DMake(placemark.location.coordinate.latitude, placemark.location.coordinate.longitude) title:paraula subTitle:[[padre.destinos objectAtIndex:i] objectForKey:@"titol"]];
            [mapView addAnnotation:nota];
            seacabo = true; // Per indicar que acaba la tasca asíncrona
        }];
        
        /*
         L'aplicació espera sense executar cap instrucció fins que acabin les tasques asíncrones.
         */
        
        while (!seacabo) {
            NSDate *oneSecond = [NSDate dateWithTimeIntervalSinceNow:1];
            [[NSRunLoop currentRunLoop] runMode:NSDefaultRunLoopMode beforeDate:oneSecond];
        }
        seacabo = false;
    }
}

@end
