//
//  ViewController.m
//  RouteOptimizer
//
//  Created by Carlos Giménez on 14/04/13.
//  Copyright (c) 2013 Carlos Giménez. All rights reserved.
//

#import "ViewController.h"
#import "celdaDireccionesCell.h"
#import "EditarSitioViewController.h"
#import "MQViewController.h"
#import "configuracionViewController.h"


@interface ViewController ()

@end

@implementation ViewController
@synthesize origen;
@synthesize destinos;
@synthesize coordenadas;
@synthesize lavista;
@synthesize ruta;

/*
 Inici de la vista, que a més és la primera que s'executa a l'iniciar l'aplicació.
 
 S'inicien totes les vistes per poder accedir a tots els elements necessaris per executar les funcions, així com els demés elements auxiliars.
 
 S'afegeixen tres adreces per començar.
 
 */

- (void)viewDidLoad
{
    [super viewDidLoad];
    ruta = [[MQRoute alloc] init];
    MQViewController *padre = [[self.tabBarController viewControllers] objectAtIndex:1];
    
    myIndicator = [[UIActivityIndicatorView alloc] initWithActivityIndicatorStyle:UIActivityIndicatorViewStyleWhiteLarge];
    
    CGRect mapFrame = CGRectMake(0, 0, self.view.frame.size.width, self.view.frame.size.height);
    
    padre.mapView = [[MQMapView alloc] initWithFrame:mapFrame];
    padre.mapView.delegate = self;
    
    [padre.view addSubview:padre.mapView];
    [padre.view sendSubviewToBack:padre.mapView];
    
    [padre.mapView setRegion:MQCoordinateRegionBetweenCoords(CLLocationCoordinate2DMake(41.3, 2.1), CLLocationCoordinate2DMake(41.5, 2.2))];
    
    padre2 = [[self.tabBarController viewControllers] objectAtIndex:2];
    padre2.instruccions = [[NSMutableArray alloc] init];
    
    configuracionViewController *padre3 = [[self.tabBarController viewControllers] objectAtIndex:3];
    [padre3 loadView];
    
    origen = [[NSMutableArray alloc] init];
    destinos = [[NSMutableArray alloc] init];
    coordenadas2 = [[NSMutableArray alloc] init];
    
    NSDictionary *direccionOrigen = [NSDictionary dictionaryWithObjects:[NSArray arrayWithObjects:@"Universitat Oberta", @"Avinguda del Tibidabo, 39, Barcelona", nil] forKeys:[NSArray arrayWithObjects:@"titol", @"adresa", nil]];
    NSDictionary *destino1 = [NSDictionary dictionaryWithObjects:[NSArray arrayWithObjects:@"Camp Nou", @"Arístides Mallol 2, Barcelona", nil] forKeys:[NSArray arrayWithObjects:@"titol", @"adresa", nil]];
    NSDictionary *destino2 = [NSDictionary dictionaryWithObjects:[NSArray arrayWithObjects:@"Cosmocaixa", @"Carrer d'Isaac Newton, 26, Barcelona", nil] forKeys:[NSArray arrayWithObjects:@"titol", @"adresa", nil]];
    
    [origen addObject:direccionOrigen];
    [destinos addObject:destino1];
    [destinos addObject:destino2];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *) tableView{
    return 2;
}

- (NSInteger)tableView: (UITableView *) tableView numberOfRowsInSection:(NSInteger) section {
    if (section == 0){
        return [origen count];
    }
    else {
        return [destinos count];
    }
    
}

/*
 Inicialització de les cel·les de la taula amb adreça i clau
 */

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *) indexPath{
    
    static NSString *CellIdentifier = @"CeldaDireccion";
    
    celdaDireccionesCell *cell = [self.tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    NSDictionary *direccion;
    
    if (indexPath.section==0) {
    direccion = [origen objectAtIndex:indexPath.row];
    }
    else {
        direccion = [destinos objectAtIndex:indexPath.row];
    }
    
    [cell.labelDireccion setText:[direccion objectForKey:@"adresa"]];
    [cell.labelClau setText:[direccion objectForKey:@"titol"]];
    
    return cell;
}


//Mida que coincideix amb el disseny de la cel·la al Storyboard
- (CGFloat)tableView: (UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *) indexPath{
    return 55;
}


/*
 Inicialitza les capçaleres amb Origen i destinacions, i el seu format.
 */
- (UIView *)tableView: (UITableView *)tableView viewForHeaderInSection:(NSInteger *)section{
    UIView *vistaHeader = [[UIView alloc] initWithFrame:CGRectMake(10.0, 0.0, 300.0, 23.0)];
    vistaHeader.backgroundColor = [UIColor orangeColor];
    
    UILabel *labelTitulo = [[UILabel alloc] initWithFrame:CGRectZero];
    labelTitulo.backgroundColor = [UIColor clearColor];
    labelTitulo.opaque=NO;
    labelTitulo.textColor = [UIColor whiteColor];
    labelTitulo.frame = CGRectMake(20.0, 0.0, 200.0, 23.0);
    
    if (section == 0) {
        labelTitulo.text=@"Origen";
    }
    else {
        labelTitulo.text=@"Destinacions";
    }
    
    [vistaHeader addSubview:labelTitulo];
    
    return vistaHeader;
    
}

/*
 Funció per geocodificar adreces. Donat un String amb l'adreça (que ja ha estat validat abans), es codifica en coordenades 2D
 */

-(CLLocationCoordinate2D) geocodifica: (NSString *) direccion {
    __block bool seacabo = false; //Control de la tasca asíncrona
    CLGeocoder *geocoder = [[CLGeocoder alloc] init];
    __block CLLocationCoordinate2D _coordenadas;
    [geocoder geocodeAddressString:direccion completionHandler:^(NSArray *placemarks, NSError *error) {
        if (error) {
            /*
             Si apareix un error de geocodificació, es mostra una alerta i s'atura la funció.
             */
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Error!" message:[NSString stringWithFormat:@"Error de geocodificació: %@",direccion] delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil];
            [self unlockUI];
            [alert show];
            return;
        }
        CLPlacemark *placemark = [placemarks objectAtIndex:0];
        _coordenadas = placemark.location.coordinate;
        seacabo = true; //fi de la tasca asíncrona
    }];
    
    //Espera mentre la tasca asíncrona s'executa
    while (!seacabo) {
        NSDate *oneSecond = [NSDate dateWithTimeIntervalSinceNow:1];
        [[NSRunLoop currentRunLoop] runMode:NSDefaultRunLoopMode beforeDate:oneSecond];
    }
    
    seacabo=false; //Reinici de la variable de control
    
    return _coordenadas;
}

/*
 Determina el tipus de ruta en funció de l'indicador de la configuració:
 
 0 indica cotxe, però es distingeix entre més ràpid i més curt, en funció de l'altre indicador
 
 1 indica bicicleta
 
 2 indica recorregut a peu
 
 Quan MapQuest ho habiliti, es farà servir Transport públic
 
 */

-(void) setRouteType {
    configuracion = [[self.tabBarController viewControllers] objectAtIndex:3];
    switch (configuracion.typeRoute.selectedSegmentIndex) {
        case 1:
            ruta.routeType=MQRouteTypeBicycle;
            break;
        case 2:
            ruta.routeType=MQRouteTypePedestrian;
            break;
        case 0:
            switch (configuracion.typeOptim.selectedSegmentIndex) {
                case 0:
                    ruta.routeType=MQRouteTypeFastest;
                    break;
                case 1:
                    ruta.routeType=MQRouteTypeShortest;
                    break;
                default:
                    ruta.routeType=MQRouteTypeFastest;
                    break;
            }
            break;
        default:
            ruta.routeType=MQRouteTypeFastest;
            break;
    }
    
}

-(void) calculaRutaWithStart:(int) withStart andEnd:(int) withEnd {

    averquepasa = false; //control de la tasca asíncrona de controlar ruta

    ruta.routeType=MQRouteTypeFastest; //Per defecte, es posa el mode de ruta Ràpid amb coxe
    [self setRouteType]; //Assignació del tipus de ruta
    /*
     Inicialització del calculador de ruta
     */
    
    ruta.delegate = self;
    MQViewController *miMapa = [[self.tabBarController viewControllers] objectAtIndex:1];
    ruta.mapView = miMapa.mapView;
    
    
    //Geocodificació en les coordenades d'origen i destinació
    
    __block CLLocationCoordinate2D coordOrigen;
    __block CLLocationCoordinate2D coordDestino;
    
    if (withStart==0) {
    coordOrigen = [self geocodifica:[[self.origen objectAtIndex:0] objectForKey:@"adresa"]];
    }
    else {
        coordOrigen = [self geocodifica:[[self.destinos objectAtIndex:withStart-1] objectForKey:@"adresa"]];
    }
    if(withEnd==0) {
       coordDestino = [self geocodifica:[[self.origen objectAtIndex:0] objectForKey:@"adresa"]];
    }
    else {
        coordDestino = [self geocodifica:[[self.destinos objectAtIndex:withEnd-1] objectForKey:@"adresa"]];
    }
    
    // S'acaba la geocodificació i es calcula la ruta entre les dues coordenades

    [ruta getRouteWithStartCoordinate:coordOrigen endCoordinate:coordDestino];

    //Espera mentre no s'ha aconseguit acabar la ruta i redactar les instruccions
    
    while (!averquepasa) {
        NSDate *oneSecond = [NSDate dateWithTimeIntervalSinceNow:1];
        [[NSRunLoop currentRunLoop] runMode:NSDefaultRunLoopMode beforeDate:oneSecond];
    }


}

/*
 Funcions per obtenir totes les permutacions possibles d'un conjunt d'elements
 */

- (NSSet *)permutationsWithoutRepetitionFromElements:(NSArray *)elements taking:(int)number
{
    return [NSSet setWithArray:[self permWithoutRepFrom:elements taking:number]];
}

- (NSArray *)permWithoutRepFrom:(NSArray *)elements taking:(int)number
{
    NSMutableArray *container = [NSMutableArray new];
    
    if (number == 1 && [elements count] > 0) {
        
        container = [self addArraysWithElements:elements toContainer:container];
        
    } else if (number > 1 && [elements count] > 0) {
        
        for (int i = 0; i < [elements count]; i++) {
            id element = elements[i];
            NSMutableArray *temp = [elements mutableCopy];
            [temp removeObjectAtIndex:i];
            for (NSArray *array in [self permWithoutRepFrom:temp taking:number - 1]) {
                container = [self addArrayByJoiningElement:element andArray:array toContainer:container];
            }
        }
        
    }
    
    return container;
}

- (NSMutableArray *)arrayWithArray:(NSArray *)array fromIndex:(int)index
{
    return [[array objectsAtIndexes:
             [NSIndexSet indexSetWithIndexesInRange:NSMakeRange(index, [array count] - index)]]
            mutableCopy];
}

- (NSMutableArray *)addArraysWithElements:(NSArray *)elements toContainer:(NSMutableArray *)container
{
    for (id elem in elements) {
        [container addObject:@[elem]];
    }
    return container;
}

- (NSMutableArray *)addArrayByJoiningElement:(id)element andArray:(NSArray *)array toContainer:(NSMutableArray *)container
{
    NSMutableArray *new = [array mutableCopy];
    [new insertObject:element atIndex:0];
    [container addObject:new];
    return container;
}


/*
 Funció d'optimització de l'ordre de les adreces
 */

-(void) optimitzaOrdre {
    /*
     Mostrem una taula numerada del 1 fins al nombre total de dades per calcular les permutacions possibles
     */
    int N = [self.destinos count]+1;
    NSMutableArray *altres= [[NSMutableArray alloc] init];
    for(int i=0;i<N-1;i++) {
        [altres addObject:[NSNumber numberWithInt:i]];
    }
    
    //Càlcul de les permutacions
    NSArray *permutacions = [self permWithoutRepFrom:altres taking:N-1];
    
    
    /*
     S'inicialitza i completa la matriu de distàncies entre tots els punts demanats.
     */
    NSInteger distancias[N][N];
    for (int i=0;i<N;i++){
        for (int j=0;j<N;j++) {
            [self calculaRutaWithStart:i andEnd:j];
            distancias[i][j] = tempsTotal;
            deltodo = true;
        }
    }
    NSMutableArray *permOpt = [[NSMutableArray alloc] init]; //Permutació òptima
    int optim = 4000000; //Temps de la permutació òptima
    int calcActual = 0; //Temps de la permutació actual
    for (int i=0;i<[permutacions count];i++) {
        
        //Distància de l'origen a la primera destinació
        NSNumber *kk = [[permutacions objectAtIndex:i] objectAtIndex:0];
        calcActual = distancias[0][kk.intValue+1];
        
        //Distància entre les següents destinacions
        for (int j=1;j<N-1;j++) {
            NSNumber *kk2 = [[permutacions objectAtIndex:i] objectAtIndex:j-1];
            NSNumber *kk3 = [[permutacions objectAtIndex:i] objectAtIndex:j];
            NSLog(@"Nodes: %i %i", kk2.intValue, kk3.intValue);
            calcActual = calcActual + distancias[kk2.intValue+1][kk3.intValue+1];
        }
        
        //Si el temps de la permutació actual és inferior a l'òptim, aquest passa a ser el nou òptim. Altrament, segueix com estava.
        
        if (calcActual<optim) {
            optim = calcActual;
            permOpt = [permutacions objectAtIndex:i];
        }
    }
    
    /*
     Intercanvi de les files de la taula per obtenir la permutació òptima
     */
    
    NSMutableArray *copia = [[NSMutableArray alloc] initWithArray:self.destinos];
    for (int i=0;i<[destinos count]; i++) {
        NSNumber *kk = [permOpt objectAtIndex:i];
        [destinos replaceObjectAtIndex:i withObject:[copia objectAtIndex:kk.intValue]];
    }
    [self.tableView reloadData];

}

// Per bloquejar l'aplicació mentre s'executa una tasca

-(void) lockUI {
    
    /*
     Indicador d'execució d'una tasca.
     */
    myIndicator.color = [UIColor redColor];
    myIndicator.center = self.view.center;
    [self.view addSubview:myIndicator];
    [myIndicator startAnimating];
    
    /*
     Bloqueig de botons i de barra d'opcions
     */
    
    [self.view setUserInteractionEnabled:NO];
    [self.tabBarController.view setUserInteractionEnabled:NO];
}

//Per desbloquejar l'aplicació quan acaba la tasca

-(void) unlockUI {
    
    [myIndicator stopAnimating]; //Desapareix l'indicador
    [self.view setUserInteractionEnabled:YES]; //Desbloqueja botons
    [self.tabBarController.view setUserInteractionEnabled:YES]; //Desbloqueja barra d'opcions
}

/*
 Accions per calcular la ruta actual, amb les dades de la taula i les opcions de configuració
 */

-(IBAction)btnClicked:(id)sender {
    deltodo=true; //Indicador per si cal reiniciar la taula d'instruccions
    [self lockUI]; //Bloquejar l'aplicació mentre s'executen les tasques
    
    /*
    Inicialització dels elements pel càlcul i s'eliminen les línies de ruta del mapa
     */
    
    configuracion = [[self.tabBarController viewControllers] objectAtIndex:3];
    MQViewController *padre = [[self.tabBarController viewControllers] objectAtIndex:1];
    NSArray *someOverlays = [padre.mapView overlays];
    [padre.mapView removeOverlays:someOverlays];
    
    /*
     Controla que hi hagi almenys una destinació per poder calcular la ruta.
     */
    
    if([destinos count] == 0) {
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Falten adreces" message:@"Per poder calcular una ruta, cal una destinació!" delegate:self cancelButtonTitle:@"OK" otherButtonTitles: nil];
        [alert show];
        [self unlockUI];
    }
    else {
    
        
        
    if ([configuracion.withOptim isOn]) { //Controla si s'ha de fer optimització o no
        /*
         Si cal fer optimització, cal que hi hagi com a mínim dues adreces per poder mirar quin ordre és millor
         */
        
        if ([destinos count] == 1) {
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Falten adreces" message:@"Per poder optimitzar calen com a mínim dos destinacions!" delegate:self cancelButtonTitle:@"OK" otherButtonTitles: nil];
            [alert show];
            [self unlockUI];
        }
        
        //Calcula la ruta inicial per saber després quant temps hem guanyat
        
        for (int i=0; i<[destinos count]; i++) {
            [self calculaRutaWithStart:i andEnd:i+1];
        }
        int tempsInicial = tempsTotal; //Temps amb l'ordre preestablert
        deltodo=true;
        [self optimitzaOrdre]; //Funció d'optimitzar l'ordre
        
        /*
         Es carrega el mapa i s'esborren les línies de ruta de la ruta anterior
         */
        
        MQViewController *padre = [[self.tabBarController viewControllers] objectAtIndex:1];
        NSArray *someOverlays = [padre.mapView overlays];
        [padre.mapView removeOverlays:someOverlays];
        
        //Càlcul de la ruta òptima
        
        for (int i=0; i<[destinos count]; i++) {
            [self calculaRutaWithStart:i andEnd:i+1];
        }
        
        int guanyat = tempsInicial - tempsTotal; //Es mira el temps que s'ha guanyat
        
        /*
         Si no s'ha guanyat temps, s'indica que l'ordre ja era òptim, amb el temps total de la ruta
         */
        
        if (guanyat == 0) {
            [self unlockUI];
            NSString *temps = [[padre2.instruccions objectAtIndex:[padre2.instruccions count]-1] objectForKey:@"acumulat"];
            UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Ruta optimitzada!" message:[NSString stringWithFormat:@"El teu ordre ja era òptim! %@", temps] delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil];
            [alert show];
        }
        
        /*
         Si s'ha guanyat temps, s'indica el temps que es pot guanyar optimitzant la ruta
         */
        
        else {
        NSString *temps = [self formattedStringForDuration:guanyat];
            [self unlockUI];
        UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Ruta optimitzada!" message:[NSString stringWithFormat:@"Amb l'optimització has guanyat: %@", temps] delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil];
        [alert show];
        }
    }
        
    /*
     Si no s'ha demanat optimització, només es fa el càlcul de la ruta actual
     */
        
    else {
    for (int i=0; i<[destinos count]; i++) {
    [self calculaRutaWithStart:i andEnd:i+1];
    }
        
        /*
         Quan acaba es mostra una alerta amb el temps total del recorregut
         */
        
    NSString *temps = [[padre2.instruccions objectAtIndex:[padre2.instruccions count]-1] objectForKey:@"acumulat"];
        [self unlockUI];
    UIAlertView *alert = [[UIAlertView alloc] initWithTitle:@"Ruta optimitzada!" message:[NSString stringWithFormat:@"Temps total de recorregut: %@", temps] delegate:self cancelButtonTitle:@"OK" otherButtonTitles:nil];
        [alert show];
    }
    }
    
}

/*
 S'afegeix una adreça prement el botó +, que conté els textos "Nom adreça" i "Nom clau", per defecte, per a què siguin modificats al formulari.
 */

- (IBAction)addAddress:(id)sender {
    NSDictionary *destino = [NSDictionary dictionaryWithObjects:[NSArray arrayWithObjects:@"Nova adreça", @"Nom clau", nil] forKeys:[NSArray arrayWithObjects:@"adresa", @"titol", nil]];
    [destinos addObject:destino];
    [self.tableView reloadData];
}

/*
 Quan es prem una cel·la, s'envia al controlador d'Editar Adreces tota la informació de la cel·la
 */

-(void) prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
    if([segue.identifier isEqualToString:@"EditarTarea"]) {
        EditarSitioViewController *eVC = [segue destinationViewController];
        eVC.padre = self;
    }
}

/*
 Funció per esborrar adreces de destinació (mai la d'origen), amb arrossegant el dit a la part dreta de la cel·la
 */

-(void) tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        if (indexPath.section == 1) {
            [destinos removeObjectAtIndex:indexPath.row];
            [self.tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationFade];
        }
    }
}

/*
 Funció per poder canviar l'ordre de les files de la taula
 */

- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath {
    return YES;
}

/*
 Funció per intercanviar dues files de la taula, en funció de si són d'origen o destinació.
 */

-(void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath
     toIndexPath:(NSIndexPath *)toIndexPath {
    if (fromIndexPath.section==0) {
        NSDictionary *dic = [origen objectAtIndex:fromIndexPath.row];
        [origen replaceObjectAtIndex:fromIndexPath.row withObject:[destinos objectAtIndex:toIndexPath.row]];
        [destinos replaceObjectAtIndex:toIndexPath.row withObject:dic];
    }
    else if (toIndexPath.section==0) {
        NSDictionary *dic = [destinos objectAtIndex:fromIndexPath.row];
        [destinos replaceObjectAtIndex:fromIndexPath.row withObject:[origen objectAtIndex:toIndexPath.row]];
        [origen replaceObjectAtIndex:toIndexPath.row withObject:dic];
    }
    else {
    NSDictionary *dic = [destinos objectAtIndex:fromIndexPath.row];
    [destinos replaceObjectAtIndex:fromIndexPath.row withObject:[destinos objectAtIndex:toIndexPath.row]];
    [destinos replaceObjectAtIndex:toIndexPath.row withObject:dic];
    }
    [self.tableView reloadData];
}

/*
 Quan es prem el botó Editar, es pot tant suprimir alguna cel·la com intercanviar les files.
 */

- (IBAction) editTable:(id)sender{
    if(self.editing)
    {
        [super setEditing:NO animated:NO];
        [self.tableView setEditing:NO animated:NO];
        [self.tableView reloadData];
        [self.navigationItem.leftBarButtonItem setTitle:@"Edit"];
        [self.navigationItem.leftBarButtonItem setStyle:UIBarButtonItemStylePlain];
    }
    else
    {
        [super setEditing:YES animated:YES];
        [self.tableView setEditing:YES animated:YES];
        [self.tableView reloadData];
        [self.navigationItem.leftBarButtonItem setTitle:@"Done"];
        [self.navigationItem.leftBarButtonItem setStyle:UIBarButtonItemStyleDone];
    }
}

/*
 Quan s'acaba de fer el càlcul, s'omple la taula d'instruccions amb totes les maniobres a seguir, i el temps emprat en cadascuna d'elles.
 */

-(void)routeLoadFinished
{
    
    padre2 = [[self.tabBarController viewControllers] objectAtIndex:2];
   
    /*
     Si cal reescriure la ruta, s'esborra la ruta escrita actualment i es posa el temps total a zero.
     */
    
    if (deltodo==true) {
        tempsTotal = 0;
        [padre2.instruccions removeAllObjects];
        deltodo=false;
    }
    
    /*
     S'omple la taula amb cada instrucció (per exemple, gira a l'esquerra pel Carrer Còrsega), el temps emprat (ex. 1 min 30 seg) i el temps acumulat fins el moment.
     */
    
    for ( MQManeuver *maneuver in ruta.maneuvers)
    {
        tempsTotal = tempsTotal + maneuver.duration;
        NSString *duracioText = [self formattedStringForDuration:maneuver.duration];
        NSString *tempsAcumulat = [self formattedStringForDuration:tempsTotal];
        NSDictionary *resumManiobra = [NSDictionary dictionaryWithObjects:[NSArray arrayWithObjects:maneuver.narrative,duracioText, tempsAcumulat, nil] forKeys:[NSArray arrayWithObjects:@"maniobra", @"temps",@"acumulat", nil]];
        [padre2.instruccions addObject:resumManiobra];
        
    }
    [padre2.tableView reloadData]; //Un cop s'ha completat la ruta, es carrega la taula d'instruccions.
    averquepasa=true; //Control de la tasca asíncrona
}

/*
 Funció per convertir el temps de la maniobra, que està en segons, a un NSString amb format d'hores, minuts i segons
 */

- (NSString*)formattedStringForDuration:(NSTimeInterval)duration
{

    NSInteger minutes = floor(duration/60);
    NSInteger seconds = round(duration - minutes * 60);
    if (duration<60) {
        return [NSString stringWithFormat:@"%d seg", seconds]; //Si només hi ha segons
    }
    if (duration > 3600) {
        NSInteger hours = floor(duration/3600);
        minutes = floor(duration/60 - hours*60);
        seconds = round(duration - minutes * 60 - hours * 3600);
        return [NSString stringWithFormat:@"%d h %d min %d seg", hours, minutes, seconds]; //Si dura més d'una hora
    }
    return [NSString stringWithFormat:@"%d min %d seg", minutes, seconds]; //Si dura més d'un minut però menys d'una hora
}


@end
