//
//  listaDireccionesViewController.m
//  Nopeus
//
//  Created by Carlos Giménez on 05/05/13.
//  Copyright (c) 2013 Carlos Giménez. All rights reserved.
//

#import "listaDireccionesViewController.h"
#import <sqlite3.h>
#import "AppDelegate.h"

/*
 
 Vista amb les adreces favorites que tenim guardades a la base de dades
 
 */

@interface listaDireccionesViewController (){
    NSMutableArray *direcciones;
}

@end

@implementation listaDireccionesViewController
@synthesize padre;

- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

/*
 
Inicialització de la taula de les adreces i càrrega de la base de dades. 
 
 */

- (void)viewDidLoad
{
    [super viewDidLoad];
    
    direcciones = [[NSMutableArray alloc] init];
    
    [self cargarDirecciones];
    
    [self.tableView reloadData];
    
	// Do any additional setup after loading the view.
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

- (NSInteger)numberOfSectionsInTableView:(UITableView *) tableView{
    return 1;
}

- (NSInteger)tableView: (UITableView *) tableView numberOfRowsInSection:(NSInteger) section {
    return [direcciones count];
}

/*
 Funció per omplir les cel·les de la taula amb dos camps, que són l'adreça i el text clau.
 */

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *) indexPath{
    
    static NSString *CellIdentifier = @"CeldaDireccion";
    
    NSDictionary *direccion = [direcciones objectAtIndex:indexPath.row];
    
    UITableViewCell *cell = [self.tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    
    if (cell == nil) {
        cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier];
    }
    
    cell.textLabel.text = [direccion objectForKey:@"adresa"];
    cell.detailTextLabel.text = [direccion objectForKey:@"titol"];
    
    return cell;
}

/*
 
 Càrrega de les adreces emmagatzemades a la base de dades SQLite
 
 */

- (void) cargarDirecciones {
    
    /*
     Inicialització de la base de dades
     */
    
    AppDelegate *appDelegate = (AppDelegate *)[[UIApplication sharedApplication] delegate];
    
    sqlite3 *database;
    sqlite3_stmt *sentencia;
    
    if (sqlite3_open([appDelegate.databasePath UTF8String],&database)==SQLITE_OK) { //obrim base de dades
        NSString *sql = [NSString stringWithFormat:@"select * from direcciones"]; //mostrem totes les adreces
        if (sqlite3_prepare_v2(database, [sql UTF8String], -1, &sentencia, NULL) == SQLITE_OK) {
            while (sqlite3_step(sentencia)==SQLITE_ROW) {
                NSString *adresa = [NSString stringWithUTF8String:(char *) sqlite3_column_text(sentencia, 0)];
                NSString *titol = [NSString stringWithUTF8String:(char *) sqlite3_column_text(sentencia, 1)];
                NSDictionary *dic = [[NSDictionary alloc] initWithObjects:[NSArray arrayWithObjects:adresa,titol, nil] forKeys:[NSArray arrayWithObjects:@"adresa", @"titol", nil]];
                [direcciones addObject:dic];
                
                //Carreguem les adreces triades per la nostra Array
            }
        }
        else {
            NSLog(@"Error al crear la sentencia"); //mostra error si hi ha algun problema amb la sentencia SQL
        }
        sqlite3_finalize(sentencia); //Tanca la sentencia SQL
    }
    else {
        NSLog(@"Error al cargar la base de datos"); //Mostra error si no es pot carregar la base
    }
    sqlite3_close(database); //Tanca base de dades
}


/*
 Un cop seleccionem una cel·la de la nostra taula, agafem les dades per introduir-les en el nostre formulari on posem les adreces.
 */


- (void)tableView: (UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *) indexPath{
    NSDictionary *dic = [direcciones objectAtIndex:indexPath.row];
    
    padre.textAdresa.text = [dic objectForKey:@"adresa"];
    padre.textClau.text = [dic objectForKey:@"titol"];
    
    [self dismissViewControllerAnimated:YES completion:nil]; //torna a la pantalla anterior
    
    
}

/*
 Funció per eliminar un registre de la taula i de la base de dades amb el botó delete.
 */

-(void) tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath {
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        /*
         Comandes per inicialitzar la base de dades;
         */
        
        AppDelegate *appDelegate = (AppDelegate *)[[UIApplication sharedApplication] delegate];
        sqlite3 *database;
        sqlite3_stmt *sentencia;
        
        if (sqlite3_open([appDelegate.databasePath UTF8String],&database)==SQLITE_OK) { //obrim la base de dades
            NSString *sql = [NSString stringWithFormat:@"delete from direcciones where direccion=\"%@\" ", [[direcciones objectAtIndex:indexPath.row] objectForKey:@"adresa"]]; // esborrem les dades de la direcció seleccionada.
            if (sqlite3_prepare_v2(database, [sql UTF8String], -1, &sentencia, NULL) == SQLITE_OK) {
                while (sqlite3_step(sentencia)==SQLITE_OK) {
                    
                }
            }
            else {
                NSLog(@"Error al crear la sentencia"); //Control d'error amb sentència
            }
            sqlite3_finalize(sentencia);
        }
        else {
            NSLog(@"Error al cargar la base de datos"); //error si no carrega bé la base de dades
        }
        sqlite3_close(database); //Tanquem la base de dades
    }
    [direcciones removeObjectAtIndex:indexPath.row]; //Eliminem el registre també de la nostra taula
    [self.tableView deleteRowsAtIndexPaths:[NSArray arrayWithObject:indexPath] withRowAnimation:UITableViewRowAnimationFade]; //Eliminem el registre de la vista
}

- (CGFloat)tableView: (UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *) indexPath{
    return 42;
}

//Torna a la vista anterior quan pulsem Enrere

- (IBAction)pulsarEnrere:(id)sender {
    [self dismissViewControllerAnimated:YES completion:nil];
    
    
}
@end
